import adonthell

class torch (adonthell.item_base):

    def __init__ (self):
        # -- init item base class (not really needed unless we do
        #    something like 'mytorch = torch ()'. Rather do
        #    'mytorch = adonthell.item_base ("torch")'
        # adonthell.item_base.init (self, self)

        # -- we need an event_list for storing time_events
        self.myevents = adonthell.event_list ()
        
        # -- flag to indicate whether the torch is on or off
        self.is_burning = 0
        
        # -- it's a new torch, after all
        self.charge = 50
        
    def use (self, user):
        # -- turn it on
        if self.is_burning == 0:

            # -- does it have enough charge?
            if self.charge == 0: return

            # -- register time event so it is consumed while burning
            #    One charge lasts 5 minutes of game time
            self.consume_event = adonthell.time_event ("5m")

            # -- callback to execute whenever a charge has been used
            #    up.
            self.consume_event.set_callback (self.on_burn)

            # -- repeat event as often as item has charges
            self.consume_event.set_repeat ("5m", self.charge)

            # -- register consume event with event_list
            self.myevents.add_event (self.consume_event)
            self.is_burning = 1

            # -- while it's burning, make it a lightsource
            self.add_type ("Lightsource")

            # -- start any graphical effects, etc
            # ...
  
        # -- switch it off
        else:
            self.is_burning = 0
            del self.consume_event

            # -- not burning, so no lightsource
            self.remove_type ("Lightsource")

            # -- remove any graphical effects, etc
            # ...

    def on_burn (self):
        # -- decrease item's charge
        self.charge = self.charge - 1

        print "Charge remaining:", self.charge
        
        # -- if no charges left, turn off torch
        if self.charge == 0:
            # -- the 'use' method will do that for us
            self.use (None)
     
    def put_state (self, file):
        # -- save state of parent class
        adonthell.item_base.put_state (self, file)

        # -- save event list
        self.myevents.put_state (self, file)

        # -- save own parameters
        # file.put_bool (is_burning)

    def get_state (self, file):
        # -- load state of parent class
        adonthell.item_base.get_state (self, file)

        # -- load event list
        self.myevents.get_state (self, file)

        # -- load own parameters
        # is_burning = file.get_bool ()

